"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getMessageForSlack = void 0;
/* eslint-disable @typescript-eslint/no-explicit-any */
const axios_1 = require("axios");
const winston_slack_webhook_transport_1 = __importDefault(require("winston-slack-webhook-transport"));
const logger_types_1 = require("../../../logger/logger.types");
const getMessageForSlack = (info, nodeEnv) => {
    const errorObject = {
        context: info.context ?? undefined,
        message: info.message ?? undefined,
        level: info.level ?? undefined,
        splat: info[Symbol.for('splat')] ?? undefined,
        data: info.data ?? undefined,
        timestamp: info.timestamp ?? undefined,
        symbolMessage: JSON.parse(info[Symbol.for('message')]) ?? undefined,
    };
    const { data, context, message } = errorObject;
    let errorMessage = message;
    const attachments = [];
    const fields = [];
    if (data !== undefined) {
        if (data instanceof Error || data instanceof axios_1.AxiosError) {
            errorMessage = data.message;
            if (data.stack !== undefined) {
                const stackParts = data.stack.split('\n');
                stackParts.forEach((part) => fields.push({
                    title: '',
                    value: part.trim(),
                    short: false,
                }));
            }
        }
    }
    attachments.push({
        // green
        color: '#36a64f',
        fields,
        footer: `*${errorObject.timestamp} - ${nodeEnv}*`.toUpperCase(),
    });
    const slackMessage = {
        attachments,
        blocks: [
            /**
             * Header
             */
            {
                type: 'header',
                text: {
                    type: 'plain_text',
                    text: ':x:The service got an error :x:',
                    emoji: true,
                },
            },
            /**
             * Level
             */
            {
                type: 'context',
                elements: [
                    {
                        type: 'mrkdwn',
                        text: `:exclamation:Error level: *${errorObject.level}*`.toUpperCase() + `:exclamation:`,
                    },
                ],
            },
            {
                type: 'divider',
            },
            /**
             * Context  Message
             */
            {
                type: 'section',
                fields: [
                    {
                        type: 'mrkdwn',
                        text: '*Context Message:*',
                    },
                    {
                        type: 'mrkdwn',
                        text: message,
                    },
                ],
            },
            {
                type: 'divider',
            },
            /**
             * Context
             */
            {
                type: 'section',
                fields: [
                    {
                        type: 'mrkdwn',
                        text: '*Context:*',
                    },
                    {
                        type: 'mrkdwn',
                        text: context,
                    },
                ],
            },
            {
                type: 'divider',
            },
            /**
             * Error Stack or Response
             */
            {
                type: 'section',
                fields: [
                    {
                        type: 'mrkdwn',
                        text: '*Error Message:*',
                    },
                    {
                        type: 'mrkdwn',
                        text: errorMessage,
                    },
                ],
            },
        ],
    };
    return slackMessage;
};
exports.getMessageForSlack = getMessageForSlack;
class SlackTransport {
    static create(nodeEnv, webhookUrl) {
        return new winston_slack_webhook_transport_1.default({
            level: logger_types_1.LOG_LEVEL.Error || logger_types_1.LOG_LEVEL.Fatal || logger_types_1.LOG_LEVEL.Emergency,
            webhookUrl,
            formatter: (info) => (0, exports.getMessageForSlack)(info, nodeEnv),
        });
    }
}
exports.default = SlackTransport;
